| rdhte-package | R Documentation |
Building on the recent developments in Calonico, Cattaneo, Farrell, Palomba, and Titiunik (2025), this package implements
estimation and inference of heterogeneous treatment effects in RD designs.
The package includes two main commands: rdhte conduct estimation and robust bias-corrected inference for conditional RD treatment effects,
for a given choice of bandwidth parameter; and rdbwhte implements automatic bandwidth selection methods.
We illustrate the methods implemented in the package rdhte using a canonical empirical application.
We also demonstrate how the package rdhte complements, and in very specific cases recovers,
the methods available in the packages rdrobust (Calonico, Cattaneo, Farrell, Titiunik (2017) and rdmulti, Cattaneo, Titiunik, VazquezBare (2020).
Commands: rdhte for estimation and inference.
rdbwhte for data-driven bandwidth selection.
Related software packages useful for inference in regression discontinuity (RD) designs are described in the website: https://rdpackages.github.io/.
Sebastian Calonico, University of California, Davis scalonico@ucdavis.edu.
Matias D. Cattaneo, Princeton University matias.d.cattaneo@gmail.com.
Max H. Farrell, University of California, Santa Barbara mhfarrell@gmail.com.
Filippo Palomba, Princeton University filippo.palomba19@gmail.com.
Rocio Titiunik, Princeton University rocio.titiunik@gmail.com.
Calonico, Cattaneo, Farrell, Palomba and Titiunik (2025): rdhte: Conditional Average Treatment Effects in RD Designs. Working paper.
Calonico, Cattaneo, Farrell, Palomba and Titiunik (2025): Treatment Effect Heterogeneity in Regression Discontinuity Designs. Working paper.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.